package com.akamai.amp360sample;


import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Window;
import android.view.WindowManager;
import android.widget.MediaController;
import android.widget.ProgressBar;

import com.akamai.amp_360.AMP360Component;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;
import com.akamai.media.errors.ErrorType;

import static android.os.Build.VERSION_CODES.M;

public class MainActivity extends AppCompatActivity implements VideoPlayerContainer.VideoPlayerContainerCallback {

    private static final String TAG = "MainActivity";
    private static final String LICENSE_KEY = "gUZB2xm6IinWvpUQMzcbZrISKpe4shOwZM5ca6VsCXWNsbryYVSRELsAEMaLpzgZKe1JdKb5WiQQTpnIZxco9Q==";

    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private AMP360Component amp360Component;
    private ProgressBar progressBar;

    private MediaResource resource;
    private boolean mWasPlaying;
    private int mCurrentPosition;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        requestWindowFeature(Window.FEATURE_NO_TITLE);
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,
                WindowManager.LayoutParams.FLAG_FULLSCREEN);

        setContentView(R.layout.activity_main);
        progressBar = (ProgressBar)findViewById(R.id.progressBar);
        videoPlayerContainer = (VideoPlayerContainer)findViewById(R.id.videoContainer);

        //360 degree video integration
        amp360Component = new AMP360Component.Builder(this)
                .setVideoPlayerContainer(videoPlayerContainer)
                .setDisplayMode(AMP360Component.DISPLAY_MODE_GLASS)
                .setInteractiveMode(AMP360Component.INTERACTIVE_MODE_TOUCH)
                .build();

        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(getResources().getString(R.string.stream));
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.e(TAG,"onVideoPlayerCreated");
    }

    @Override
    public void onResourceReady(MediaResource resource) {
        Log.e(TAG,"onResourceReady");
        this.resource = resource;
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setProgressBarControl(progressBar);
        videoPlayerView.setLicense(LICENSE_KEY);
        videoPlayerView.play(resource);
    }

    @Override
    public void onResourceError(ErrorType errorType, Exception exception) {

        Log.e(TAG,"onResourceError");
    }

    @Override
    protected void onPause() {

        if(videoPlayerView != null && videoPlayerView.isPlaying()){
            mCurrentPosition = videoPlayerView.getTimePosition();
            videoPlayerView.stop();
            mWasPlaying = true;
            amp360Component.onPause();
        }

        super.onPause();
    }

    @Override
    protected void onResume() {
        if (videoPlayerView != null && mWasPlaying) {
            videoPlayerView.play(resource, mCurrentPosition);
            amp360Component.onResume();
        }
        super.onResume();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        amp360Component.onDestroy();
    }

}
